@@ -21,7 +21,7 @@
 #pragma implementation
 #include "HDSPMixerOutput.h"
 
-static char *labels_madi_ss[64] = {
+static char const *labels_madi_ss[64] = {
    "1",  "2",  "3",  "4",  "5",  "6",  "7",  "8",
    "9", "10", "11", "12", "13", "14", "15", "16", 
   "17", "18", "19", "20", "21", "22", "23", "24", 
@@ -32,20 +32,25 @@ static char *labels_madi_ss[64] = {
   "57", "58", "59", "60", "61", "62", "63", "64"
 };
 
-static char *labels_madi_ds[64] = {
+static char const *labels_madi_ds[64] = {
    "1",  "2",  "3",  "4",  "5",  "6",  "7",  "8",
    "9", "10", "11", "12", "13", "14", "15", "16", 
   "17", "18", "19", "20", "21", "22", "23", "24", 
   "25", "26", "27", "28", "29", "30", "31", "32", 
 };
 
-static char *labels_madi_qs[16] = {
+static char const *labels_madi_qs[16] = {
    "1",  "2",  "3",  "4",  "5",  "6",  "7",  "8",
    "9", "10", "11", "12", "13", "14", "15", "16", 
 };
 
 
-static char *labels_raydat_ss[36] = {
+static char const *labels_aes32[16] = {
+  "AES 1", "AES 2", "AES 3", "AES 4", "AES 5", "AES 6", "AES 7", "AES 8",
+  "AES 9", "AES 10", "AES 11", "AES 12", "AES 13", "AES 14", "AES 15", "AES 16"
+};
+
+static char const *labels_raydat_ss[36] = {
   "A1.1", "A1.2", "A1.3", "A1.4", "A1.5", "A1.6", "A1.7", "A1.8",
   "A2.1", "A2.2", "A2.3", "A2.4", "A2.5", "A2.6", "A2.7", "A2.8",
   "A3.1", "A3.2", "A3.3", "A3.4", "A3.5", "A3.6", "A3.7", "A3.8",
@@ -54,7 +59,7 @@ static char *labels_raydat_ss[36] = {
   "SP.L", "SP.R"
 };
 
-static char *labels_raydat_ds[20] = {
+static char const *labels_raydat_ds[20] = {
   "A1.1", "A1.2", "A1.3", "A1.4",
   "A2.1", "A2.2", "A2.3", "A2.4",
   "A3.1", "A3.2", "A3.3", "A3.4",
@@ -63,7 +68,7 @@ static char *labels_raydat_ds[20] = {
   "SP.L", "SP.R"
 };
 
-static char *labels_raydat_qs[12] = {
+static char const *labels_raydat_qs[12] = {
   "A1.1", "A1.2",
   "A2.1", "A2.2",
   "A3.1", "A3.2",
@@ -72,101 +77,116 @@ static char *labels_raydat_qs[12] = {
   "SP.L", "SP.R"
 };
 
-
-static char *labels_aio_ss_input[14] = {
-  "AN 1",  "AN 2",
-  "SP.L", "SP.R",
-  "AES.L",  "AES.R",
-  "A 1", "A 2", "A 3", "A 4",
-  "A 5", "A 6", "A 7", "A 8"
+static char const *labels_rpm_output[6] = {
+  "Main L", "Main R", "Mon L", "Mon R", "PH L", "PH R"
 };
 
-static char *labels_aio_ss_playback[16] = {
+static char const *labels_rpm_input[5] = {
+  "Phono 1.L", "Phono 1.R",
+  "Phono 2.L", "Phono 2.R",
+  "Mic"
+};
+
+static char const *labels_aio_ss_input[18] = {
   "AN 1",  "AN 2",
   "SP.L", "SP.R",
   "AES.L",  "AES.R",
   "A 1", "A 2", "A 3", "A 4",
   "A 5", "A 6", "A 7", "A 8",
-  "PH.L", "PH.R"
+  "AEB 1", "AEB 2", "AEB 3," "AEB 4"
 };
 
-static char *labels_aio_ds_input[10] = {
-  "AN 1",  "AN 2",  
+static char const *labels_aio_ss_playback[20] = {
+  "AN 1",  "AN 2",
   "SP.L", "SP.R",
   "AES.L",  "AES.R",
-  "A 1", "A 2", "A 3", "A 4"
+  "A 1", "A 2", "A 3", "A 4",
+  "A 5", "A 6", "A 7", "A 8",
+  "PH.L", "PH.R",
+  "AEB 1", "AEB 2", "AEB 3", "AEB 4"
 };
 
-static char *labels_aio_ds_playback[12] = {
+static char const *labels_aio_ds_input[14] = {
   "AN 1",  "AN 2",  
   "SP.L", "SP.R",
   "AES.L",  "AES.R",
   "A 1", "A 2", "A 3", "A 4",
-  "PH.L", "PH.R"
+  "AEB 1", "AEB 2", "AEB 3", "AEB 4"
+};
+
+static char const *labels_aio_ds_playback[16] = {
+  "AN 1",  "AN 2",  
+  "SP.L", "SP.R",
+  "AES.L",  "AES.R",
+  "A 1", "A 2", "A 3", "A 4",
+  "PH.L", "PH.R",
+  "AEB 1", "AEB 2", "AEB 3", "AEB 4"
  };
 
-static char *labels_aio_qs_input[8] = {
+static char const *labels_aio_qs_input[12] = {
   "AN 1",  "AN 2",
   "SP.L", "SP.R",
   "AES.L",  "AES.R",
-  "A 1", "A 2"
+  "A 1", "A 2",
+  "AEB 1", "AEB 2", "AEB 3", "AEB 4"
 };
 
-static char *labels_aio_qs_playback[10] = {
+static char const *labels_aio_qs_playback[14] = {
   "AN 1",  "AN 2",
   "SP.L", "SP.R",
   "AES.L",  "AES.R",
   "A 1", "A 2",
   "PH.L", "PH.R",
+  "AEB 1", "AEB 2", "AEB 3", "AEB 4"
 };
 
 
-static char *labels_mf_ss[20] = {
+static char const *labels_mf_ss[20] = {
     "AN 1", "AN 2", "AN 3", "AN 4", "AN 5", "AN 6", "AN 7", "AN 8",
     "A 1", "A 2", "A 3", "A 4", "A 5", "A 6", "A 7", "A 8",
     "SP.L", "SP.R", "AN.L", "AN.R"
 };
 
-static char *labels_mf_ds[16] = {
+static char const *labels_mf_ds[16] = {
     "AN 1", "AN 2", "AN 3", "AN 4", "AN 5", "AN 6", "AN 7", "AN 8",
     "A 1", "A 2", "A 3", "A 4",
     "SP.L", "SP.R", "AN.L", "AN.R"
 };
 
 
-static char *labels_df_ss[28] = {
+static char const *labels_df_ss[28] = {
     "A1 1", "A1 2", "A1 3", "A1 4", "A1 5", "A1 6", "A1 7", "A1 8",
     "A2 1", "A2 2", "A2 3", "A2 4", "A2 5", "A2 6", "A2 7", "A2 8",
     "A3 1", "A3 2", "A3 3", "A3 4", "A3 5", "A3 6", "A3 7", "A3 8",
     "SP.L", "SP.R", "AN.L", "AN.R"
 };
 
-static char *labels_df_ds[16] = {
+static char const *labels_df_ds[16] = {
     "A1 1", "A1 2", "A1 3", "A1 4",
     "A2 1", "A2 2", "A2 3", "A2 4",
     "A3 1", "A3 2", "A3 3", "A3 4",
     "SP.L", "SP.R", "AN.L", "AN.R"
 };
 
-static char *labels_9632_ss[16] = {
+static char const *labels_9632_ss[16] = {
     "A 1", "A 2", "A 3", "A 4", "A 5", "A 6", "A 7", "A 8",
     "SP.L", "SP.R", "AN 1", "AN 2", "AN 3", "AN 4", "AN 5", "AN 6"
 };
 
-static char *labels_9632_ds[12] = {
+static char const *labels_9632_ds[12] = {
     "A 1", "A 2", "A 3", "A 4",
     "SP.L", "SP.R", "AN 1", "AN 2", "AN 3", "AN 4", "AN 5", "AN 6"
 };
 
-static char *labels_9632_qs[8] = {
+static char const *labels_9632_qs[8] = {
     "SP.L", "SP.R", "AN 1", "AN 2", "AN 3", "AN 4", "AN 5", "AN 6"
 };
 
 HDSPMixerOutput::HDSPMixerOutput(int x, int y, int w, int h, int num):Fl_Group(x, y, w, h)
 {
 
-    for (int j = 0; j < 3; ++j) {
-	for (int i = 0; i < 8; ++i) {
+    for (int j = 0; j < MAX_CARDS; ++j) {
+	for (int i = 0; i < NUM_PRESETS; ++i) {
 	    data[j][0][i] = new HDSPMixerOutputData();
 	    data[j][1][i] = new HDSPMixerOutputData();
 	    data[j][2][i] = new HDSPMixerOutputData();
@@ -193,69 +213,98 @@ void HDSPMixerOutput::setLabels()
     int sm = basew->cards[basew->current_card]->speed_mode;
 
     if (type == H9632) {
-	switch (sm) {
-	case 0:
-	    labels_input = labels_playback = labels_9632_ss;
-	    break;
-	case 1:
-	    labels_input = labels_playback = labels_9632_ds;
-	    break;	
-	case 2:
-	    labels_input = labels_playback = labels_9632_qs;
-	    break;
-	}
-    } else if (type == Multiface) {
-	if (sm)
-	    labels_input = labels_playback = labels_mf_ds;
-	else 
-	    labels_input = labels_playback = labels_mf_ss;
-	} else if (type == Digiface) {
-	if (sm)
-	    labels_input = labels_playback = labels_df_ds;
-	else
-	    labels_input = labels_playback = labels_df_ss;
-    } else if (HDSPeMADI == type) {
-      switch (sm) {
-	case 0:
-	    labels_input = labels_playback = labels_madi_ss;
-	    break;
-	case 1:
-	    labels_input = labels_playback = labels_madi_ds;
-	    break;	
-	case 2:
-	    labels_input = labels_playback = labels_madi_qs;
-	    break;
-	}
-    } else if (HDSPeAIO == type) {
-      	switch (sm) {
-	case 0:
-	    labels_input = labels_aio_ss_input;
-	    labels_playback = labels_aio_ss_playback;
-	    break;
-	case 1:
-	    labels_input = labels_aio_ds_input;
-	    labels_playback = labels_aio_ds_playback;
-	    break;	
-	case 2:
-	    labels_input = labels_aio_qs_input;
-	    labels_playback = labels_aio_ds_playback;
-	    break;
-	}
-    } else if (HDSPeRayDAT == type) {
-      switch (sm) {
-      case 0:
-	labels_input = labels_playback = labels_raydat_ss;
-	break;
-      case 1:
-	labels_input = labels_playback = labels_raydat_ds;
-	break;	
-      case 2:
-	labels_input = labels_playback = labels_raydat_qs;
-	break;
-      }
-    } else {
-      fprintf(stderr, "Unknown card type for output labels\n");
+        switch (sm) {
+            case 0:
+                labels_input = labels_playback = labels_9632_ss;
+                break;
+            case 1:
+                labels_input = labels_playback = labels_9632_ds;
+                break;	
+            case 2:
+                labels_input = labels_playback = labels_9632_qs;
+                break;
+        }
+        return;
     }
+    
+    if (type == Multiface) {
+        if (sm)
+            labels_input = labels_playback = labels_mf_ds;
+        else 
+            labels_input = labels_playback = labels_mf_ss;
+        return;
+    };
+
+    if (type == RPM) {
+        labels_input = labels_rpm_input;
+        labels_playback = labels_rpm_output;
+        return;
+    };
+    
+    if (type == Digiface || type == H9652) {
+        if (sm)
+            labels_input = labels_playback = labels_df_ds;
+        else
+            labels_input = labels_playback = labels_df_ss;
+        return;
+    }
+    
+    
+    if (HDSPeMADI == type) {
+        switch (sm) {
+            case 0:
+                labels_input = labels_playback = labels_madi_ss;
+                break;
+            case 1:
+                labels_input = labels_playback = labels_madi_ds;
+                break;	
+            case 2:
+                labels_input = labels_playback = labels_madi_qs;
+                break;
+        }
+        return;
+    }
+
+    if (HDSP_AES == type) {
+        labels_input = labels_playback = labels_aes32;
+        return;
+    }
+    
+    if (HDSPeAIO == type) {
+        switch (sm) {
+            case 0:
+                labels_input = labels_aio_ss_input;
+                labels_playback = labels_aio_ss_playback;
+                break;
+            case 1:
+                labels_input = labels_aio_ds_input;
+                labels_playback = labels_aio_ds_playback;
+                break;	
+            case 2:
+                labels_input = labels_aio_qs_input;
+                labels_playback = labels_aio_ds_playback;
+                break;
+        }
+        return;
+    }
+    
+    if (HDSPeRayDAT == type) {
+        switch (sm) {
+            case 0:
+                labels_input = labels_playback = labels_raydat_ss;
+                break;
+            case 1:
+                labels_input = labels_playback = labels_raydat_ds;
+                break;	
+            case 2:
+                labels_input = labels_playback = labels_raydat_qs;
+                break;
+        }
+        return;
+    }
+    
+    fprintf(stderr, "Unknown card type for output labels, assigning defaults\n");
+    labels_input = labels_playback = labels_madi_ss;
 }
 
 void HDSPMixerOutput::draw_background()
@@ -275,7 +324,7 @@ void HDSPMixerOutput::draw()
     Fl_Widget*const* a = array();
     if (damage() & ~FL_DAMAGE_CHILD) {
 	draw_background();
-	fl_color(FL_BLACK);
+	fl_color(FL_FOREGROUND_COLOR);
 	fl_font(FL_HELVETICA, 8);
 	fl_draw(labels_playback[out_num], x()+4, y()+193, 27, 9, FL_ALIGN_CENTER);
 	for (int i=children(); i--;) {
