@@ -32,22 +32,22 @@ char Cus428Midi::KnobParam[] = {
 	0x2A,
 	0x29,
 	0x28,
-	-1,
+	(char)-1,
 	0x10,
 	0x11,
 	0x18,
 	0x19,
 	0x1A,
-	-1,
-	-1,
-	-1,
-	-1,
+	(char)-1,
+	(char)-1,
+	(char)-1,
+	(char)-1,
 	0x2C,
 	0x2D,
 	0x2E,
 	0x2F,
-	-1,
-	-1,
+	(char)-1,
+	(char)-1,
 	0x20,
 	0x21,
 	0x22,
@@ -64,14 +64,14 @@ char Cus428Midi::KnobParam[] = {
 	5,
 	6,
 	7,
-	-1,
-	-1,
-	-1,
-	-1,
-	-1,
-	-1,
-	-1,
-	-1,
+	(char)-1,
+	(char)-1,
+	(char)-1,
+	(char)-1,
+	(char)-1,
+	(char)-1,
+	(char)-1,
+	(char)-1,
 	0x30,
 	0x31,
 	0x32,
